@@ -1,41 +1,39 @@
-# Copyright (c) 2010 gocept gmbh & co. kg
+# Copyright (c) 2012 gocept gmbh & co. kg
 # See also LICENSE.txt
 
-import fcntl
+from .platform import flock_exclusive
+import contextlib
 import os
 import os.path
-import pwd
-from contextlib import contextmanager
 
 
 class Cookie(object):
     """Status information for plugins that is persisted between runs.
 
-    Nagios Plugins may keep track of details like the last position in a logfile
-    etc. Cookie helps with that task: a string is kept between runs. The cookie
-    is identified with a file name (the file goes into $HOME by default, which
-    is /var/nagios on most systems). The plugin is responsible for
-    serializing/deserializing that information. Human-readable ASCII text is
-    strongly preferred.
+    Nagios Plugins may keep track of details like the last position in a
+    logfile etc. Cookie helps with that task: a string is kept between
+    runs. The cookie is identified with a file name (the file goes into
+    $HOME by default, which is /var/nagios on most systems). The plugin
+    is responsible for serializing/deserializing that information.
+    Human-readable ASCII text is strongly preferred.
     """
 
-    def __init__(self, filename, dir=None):
+    def __init__(self, filename, directory=None):
         """Create new or lookup existing cookie.
 
         `filename` is the file where the cookie lives.
-        `dir` defaults to the home directory.
+        `directory` defaults to the home directory.
         """
-        if dir:
-            self.filename = os.path.join(os.path.abspath(dir), filename)
+        if directory:
+            self.filename = os.path.join(os.path.abspath(directory), filename)
         elif filename.startswith('/'):
             self.filename = os.path.abspath(filename)
         else:
-            home = pwd.getpwuid(os.getuid()).pw_dir
-            self.filename = os.path.join(os.path.expanduser(home), filename)
+            self.filename = os.path.join(os.path.expanduser('~'), filename)
         self.new = not os.path.exists(self.filename)
         self.changed = False
         self.f = file(self.filename, 'a+')
-        fcntl.lockf(self.f, fcntl.LOCK_EX)
+        flock_exclusive(self.f)
         self.cur_value = None
         self.new_value = None
 
@@ -67,7 +65,7 @@ class Cookie(object):
             os.unlink(self.filename)
 
 
-@contextmanager
+@contextlib.contextmanager
 def store(filename, dir=None):
     """Encapsulate init/close into `with` block."""
     c = Cookie(filename, dir)
